@@ -8,7 +8,7 @@ use strict;
 use Carp;
 use English qw( -no_match_vars );
 use constant ERROR_CONTEXT => 3;
-{ our $VERSION = '1.60'; }
+{ our $VERSION = '1.62'; }
 use Scalar::Util qw< blessed reftype >;
 
 # Function-oriented interface
@@ -249,7 +249,8 @@ sub traverse {  ## no critic (RequireArgUnpacking,ProhibitExcessComplexity)
       # if $ref is not true, we hit a wall. How we proceed depends on
       # whether we were asked to auto-vivify or not.
       if (!$ref) {
-         return '' unless $ref_wanted;    # don't bother going on
+         return (exists($opts->{missing}) ? $opts->{missing} : '')
+            unless $ref_wanted;    # don't bother going on
 
          # auto-vivification requested! $key will tell us how to
          # proceed further, hopefully
